@@ -55,6 +55,10 @@ class OpsaniDevConfiguration(servo.BaseConfiguration):
     cpu: CPU
     memory: Memory
     prometheus_base_url: str = PROMETHEUS_SIDECAR_BASE_URL
+    timeout: servo.Duration = "5m"
+    settlement: Optional[servo.Duration] = pydantic.Field(
+        description="Duration to observe the application after an adjust to ensure the deployment is stable. May be overridden by optimizer supplied `control.adjust.settlement` value."
+    )
 
     @classmethod
     def generate(cls, **kwargs) -> "OpsaniDevConfiguration":
@@ -78,6 +82,8 @@ class OpsaniDevConfiguration(servo.BaseConfiguration):
         return servo.connectors.kubernetes.KubernetesConfiguration(
             namespace=self.namespace,
             description="Update the namespace, deployment, etc. to match your Kubernetes cluster",
+            timeout=self.timeout,
+            settlement=self.settlement,
             deployments=[
                 servo.connectors.kubernetes.DeploymentConfiguration(
                     name=self.deployment,
@@ -594,7 +600,11 @@ class OpsaniDevChecks(servo.BaseChecks):
             if container.name == "opsani-envoy":
                 return
 
-        command = f"kubectl exec -n {self.config.namespace} -c servo {self._servo_resource_target} -- servo --token-file /servo/opsani.token inject-sidecar -n {self.config.namespace} -s {self.config.service} deployment/{self.config.deployment}"
+        port_switch = (
+            f" --port {self.config.port}" if self.config.port is not None
+            else ''
+        )
+        command = f"kubectl exec -n {self.config.namespace} -c servo {self._servo_resource_target} -- servo --token-file /servo/opsani.token inject-sidecar --namespace {self.config.namespace} --service {self.config.service}{port_switch} deployment/{self.config.deployment}"
         raise servo.checks.CheckError(
             f"deployment '{deployment.name}' pod template spec does not include envoy sidecar container ('opsani-envoy')",
             hint=f"Inject Envoy sidecar container via: `{command}`",
@@ -696,9 +706,13 @@ class OpsaniDevChecks(servo.BaseChecks):
             deployment_config, timeout=kubernetes_config.timeout
         )
 
-        # Ensure the canary is available
+        # Ensure the tuning pod is available
         try:
-            await optimization.create_or_recreate_tuning_pod()
+            if optimization.tuning_pod is None:
+                servo.logger.info(f"Creating tuning pod '{optimization.tuning_pod_name}'")
+                await optimization.create_tuning_pod()
+            else:
+                servo.logger.info(f"Found existing tuning pod '{optimization.tuning_pod_name}'")
 
         except Exception as error:
             servo.logger.exception("Failed creating tuning Pod: {error}")
